"""
PyIter is a Python package for iterative operations inspired by the Kotlin、CSharp(linq)、
TypeSrcipt and Rust . Enables strong typing and type inference for iterative operations.
"""

from .sequence import Sequence, sequence, seq, iterate, it

__ALL__ = [Sequence, sequence, seq, iterate, it]
